SWDEV-339113 - Update sampl codes with correct kernel coordinate (#2704)

Change-Id: Ibfc0fd285441cd3d79b312d2b739729a039a6f84
This commit is contained in:
ROCm CI Service Account
2022-06-02 17:07:52 +05:30
committed by GitHub
parent f6f8a0d144
commit e6ded45898
14 changed files with 47 additions and 47 deletions
+1 -1
View File
@@ -36,7 +36,7 @@ THE SOFTWARE.
// 'out'
// but it will update with "NOT_SUPPORTED" for any other gfx archs.
__global__ void incrementKernel(int32_t* in, int32_t* out, int32_t value, size_t buffSize) {
int index = hipBlockDim_x * hipBlockIdx_x + hipThreadIdx_x;
int index = blockDim.x * blockIdx.x + threadIdx.x;
if (index < buffSize) {
#if defined(__gfx908__)
out[index] = in[index] + value;